//=======================================================================
// Author: Donovan Parks
//
// Copyright 2011 Donovan Parks
//
// This file is part of ExpressBetaDiversity.
//
// ExpressBetaDiversity is free software: you can redistribute it 
// and/or modify it under the terms of the GNU General Public License 
// as published by the Free Software Foundation, either version 3 of 
// the License, or (at your option) any later version.
//
// ExpressBetaDiversity is distributed in the hope that it will be 
// useful, but WITHOUT ANY WARRANTY; without even the implied warranty
// of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with ExpressBetaDiversity. If not, see 
// <http://www.gnu.org/licenses/>.
//=======================================================================

#include "Precompiled.hpp"

#include "Node.hpp"

const double Node::NO_DISTANCE = -1;
const uint Node::NO_INDEX = std::numeric_limits<uint>::max();

Node::Node(const std::string& name)
	: m_name(name), m_parent(NULL), m_distanceToParent(NO_DISTANCE), m_seqIndex(NO_INDEX), m_postOrderIndex(NO_INDEX)
{

}

Node::Node(const Node &rhs)
{
	m_name = rhs.GetName();
	m_distanceToParent = rhs.GetDistanceToParent();
	m_seqIndex = rhs.GetSeqIndex();
	m_postOrderIndex = rhs.GetPostOrderIndex();
	
	m_parent = NULL;
	m_children.clear();
}

Node& Node::operator=(const Node &rhs)
{
	if(this != &rhs)
	{
		m_name = rhs.GetName();
		m_distanceToParent = rhs.GetDistanceToParent();
		m_seqIndex = rhs.GetSeqIndex();
		m_postOrderIndex = rhs.GetPostOrderIndex();
	
		m_parent = NULL;
		m_children.clear();
	}

  return *this;
}